@@ -7,26 +7,35 @@ from typing import Dict, Iterator, List, Optional, Tuple, Union
 
 # from pandas import DataFrame
 from pynmrstar import Entry, Loop, Saveframe
+from pynmrstar.definitions import STR_CONVERSION_DICT
 from pynmrstar.exceptions import ParsingError
 from strenum import LowercaseStrEnum
 
 from nef_pipelines.lib import util
-from nef_pipelines.lib.constants import NEF_PIPELINES, NEF_PIPELINES_VERSION
+from nef_pipelines.lib.constants import NEF_PIPELINES
 from nef_pipelines.lib.util import (
     exit_error,
     fixup_metadata,
+    get_version,
     is_float,
     is_int,
     running_in_pycharm,
     script_name,
 )
 
+NEF_TRUE = "true"
+NEF_FALSE = "false"
+NEF_NONE = "none"
+
 NEF_CATEGORY_ATTR = "__NEF_CATEGORY__"
 NEF_MOLECULAR_SYSTEM = "nef_molecular_system"
 NEF_METADATA = "nef_nmr_meta_data"
 
 UNUSED = "."
 
+# this stops pynmrstar failing on empty strings
+STR_CONVERSION_DICT[""] = UNUSED
+
 
 class BadNefFileException(Exception):
     """
@@ -137,8 +146,9 @@ def select_frames_by_name(
     :return: a list or matching frames
     """
 
-    def match_frames(frames, name_selectors):
-
+    def match_frames(
+        frames: List[Saveframe], name_selectors: List[str]
+    ) -> List[Saveframe]:
         result = {}
 
         for frame in frames:
@@ -194,29 +204,58 @@ def create_entry_from_stdin() -> Optional[Entry]:
     return entry
 
 
+def read_file_or_exit(file_path: Path) -> List[str]:
+    """
+    read the contenst of a file or exit with error
+
+    :param file_path: the path to the file
+    :return: a list of strings from the file
+    """
+    try:
+        result = open(file_path).readlines()
+    except IOError as e:
+        msg = f"""\
+            failed to read from {file_path} because {e}
+        """
+        exit_error(msg)
+
+    return result
+
+
 # refactor to two functions one of which gets a TextIO
-def create_entry_from_stdin_or_exit() -> Entry:
+def read_entry_from_stdin_or_exit() -> Entry:
 
     """
     read a star file entry from stdin or exit with an error message
     :return: a star file entry
     """
 
-    try:
-        if not sys.stdin.isatty() or running_in_pycharm():
-            stdin_lines = sys.stdin.read()
-            if stdin_lines is None:
-                lines = ""
-            else:
-                lines = "".join(stdin_lines)
+    if sys.stdin.isatty():
+        exit_error("you appear to be reading from an empty stdin")
 
-            if len(lines.strip()) == 0:
-                exit_error("stdin is empty")
-            else:
-                entry = Entry.from_string(lines)
-        else:
-            exit_error("you appear to be reading from an empty stdin")
-    except Exception as e:
+    if running_in_pycharm():
+        exit_error("streaming doesn't work inside pycharm")
+
+    try:
+        stdin_lines = sys.stdin.read()
+        if stdin_lines is None:
+            lines = [
+                "",
+            ]
+        lines = "".join(stdin_lines)
+    except IOError as e:
+        exit_error(
+            f"failed to read stdin because: {e}",
+            e,
+        )
+
+    if len(lines.strip()) == 0:
+        exit_error("stdin is empty")
+
+    try:
+        entry = Entry.from_string(lines)
+
+    except ParsingError as e:
         exit_error(
             f"failed to read nef entry from stdin because the NEF parser replied: {e}",
             e,
@@ -264,6 +303,10 @@ def do_reasonable_type_conversions(value: str) -> Union[str, float, int]:
         value = int(value)
     elif is_float(value):
         value = float(value)
+    elif value.lower() == NEF_FALSE:
+        value = False
+    elif value.lower() == NEF_TRUE:
+        value = True
     return value
 
 
@@ -332,7 +375,7 @@ def read_entry_from_file_or_stdin_or_exit_error(file: Path) -> Entry:
     :return:
     """
     if file is None or file == Path("-"):
-        entry = create_entry_from_stdin_or_exit()
+        entry = read_entry_from_stdin_or_exit()
     else:
         try:
             with open(file) as fh:
@@ -460,7 +503,7 @@ def add_frames_to_entry(entry: Entry, frames: List[Saveframe]) -> Entry:
         the updated entry containing the frames
     """
 
-    fixup_metadata(entry, NEF_PIPELINES, NEF_PIPELINES_VERSION, script_name(__file__))
+    fixup_metadata(entry, NEF_PIPELINES, get_version(), script_name(__file__))
 
     for frame in frames:
 
