@@ -8,7 +8,7 @@ import typer
 from tabulate import tabulate
 
 from nef_pipelines.lib.nef_lib import (
-    create_entry_from_stdin_or_exit,
+    read_entry_from_stdin_or_exit,
     select_frames_by_name,
 )
 from nef_pipelines.lib.shift_lib import nef_frames_to_shifts
@@ -58,7 +58,7 @@ def shifts(
     if len(shift_frames) == 0:
         shift_frames = ["*"]
 
-    entry = create_entry_from_stdin_or_exit()
+    entry = read_entry_from_stdin_or_exit()
 
     output_file = f"{entry.entry_id}_shifts.tab" if output_file is None else output_file
 
@@ -83,10 +83,12 @@ def shifts(
 
         # first deal with completely unassigned residues chain_code @- and sequence_code @xxxx where xxx
         # is the pseudo residue
-        chain_code = shift.atom.residue.chain_code
-        sequence_code = shift.atom.residue.sequence_code
+        chain_code = str(shift.atom.residue.chain_code)
+        sequence_code = str(shift.atom.residue.sequence_code)
         atom_name = shift.atom.atom_name
-        if chain_code.startswith("@-") and sequence_code.startswith("@"):
+        if (
+            chain_code.startswith("@") or chain_code.startswith("#")
+        ) and sequence_code.startswith("@"):
             sequence_code = sequence_code.lstrip("@")
             sequence_code_fields = sequence_code.split("-")
 
